pub struct WriterPool { /* private fields */ }Expand description
Pool of per-table writers, creating files on demand.
Implementations
Sourceimpl WriterPool
impl WriterPool
Sourcepub fn new(output_dir: PathBuf) -> Self
pub fn new(output_dir: PathBuf) -> Self
Create a new writer pool targeting the given output directory.
Sourcepub fn ensure_output_dir(&self) -> Result<()>
pub fn ensure_output_dir(&self) -> Result<()>
Create the output directory if it does not exist.
Sourcepub fn get_writer(&mut self, table_name: &str) -> Result<&mut TableWriter>
pub fn get_writer(&mut self, table_name: &str) -> Result<&mut TableWriter>
Get or create a writer for the given table name.
Sourcepub fn write_statement(&mut self, table_name: &str, stmt: &[u8]) -> Result<()>
pub fn write_statement(&mut self, table_name: &str, stmt: &[u8]) -> Result<()>
Write a statement to the file for the given table.